function Component() {
    return(/*#__PURE__*/ React.createElement("div", {
        name: "A B"
    }));
}
